@@ -78,10 +78,10 @@ forceNetwork <- function(Links, Nodes, Source, Target, Value, NodeID,
     linkColour = "#666",opacity = 0.6)
 {
     # Subset data frames for network graph
-    if (class(Links) != "data.frame"){
+    if (!is.data.frame(Links)){
         stop("Links must be a data frame class object.")
     }
-    if (class(Nodes) != "data.frame"){
+    if (!is.data.frame(Nodes)){
         stop("Nodes must be a data frame class object.")
     }
     if (missing(Value)){
